# -*- coding: utf-8 -*-

"""Views for graphene-django-sentry."""


import sentry_sdk
from graphene_django.views import GraphQLView
from graphene_file_upload.django import FileUploadGraphQLView


class SentryGraphQLView(GraphQLView):
    def execute_graphql_request(self, *args, **kwargs):
        """Extract any exceptions and send them to Sentry"""
        result = super().execute_graphql_request(*args, **kwargs)
        if result and result.errors:
            self._capture_sentry_exceptions(result.errors)
        return result

    def _capture_sentry_exceptions(self, errors):
        for error in errors:
            try:
                sentry_sdk.capture_exception(error.original_error)
            except AttributeError:
                sentry_sdk.capture_exception(error)


class SentryFileUploadGraphQLView(SentryGraphQLView, FileUploadGraphQLView):
    pass
